@@ -26,7 +26,6 @@
 
 #include <KContacts/PhoneNumber>
 #include <KContacts/VCardConverter>
-#include <kcontacts_version.h>
 
 #include <KCalUtils/IncidenceFormatter>
 #include <KCalendarCore/Calendar>
@@ -37,7 +36,7 @@
 #include <QBuffer>
 #include <QTimeZone>
 
-#include <time.h>
+#include <ctime>
 
 using namespace KCalendarCore;
 using namespace KTnef;
@@ -83,7 +82,7 @@ static QDateTime pureISOToLocalQDateTime(const QString &dtStr)
         }
         return dT;
     } else {
-        return QDateTime();
+        return {};
     }
 }
 //@endcond
@@ -312,17 +311,11 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
             } else if (bCompatClassNote || QLatin1String("IPM.CONTACT") == msgClass) {
                 addressee.setUid(stringProp(tnefMsg, attMSGID));
                 addressee.setFormattedName(stringProp(tnefMsg, MAPI_TAG_PR_DISPLAY_NAME));
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-                addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL1EMAILADDRESS)), true);
-                addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL2EMAILADDRESS)), false);
-                addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL3EMAILADDRESS)), false);
-#else
                 KContacts::Email email(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL1EMAILADDRESS)));
                 email.setPreferred(true);
                 addressee.addEmail(email);
                 addressee.addEmail(KContacts::Email(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL2EMAILADDRESS))));
                 addressee.addEmail(KContacts::Email(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL3EMAILADDRESS))));
-#endif
                 addressee.insertCustom(QStringLiteral("KADDRESSBOOK"),
                                        QStringLiteral("X-IMAddress"),
                                        sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_IMADDRESS)));
@@ -416,7 +409,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
     }
 
     // Compose return string
-    const QString iCal = calFormat.toString(cal, QString());
+    const QString iCal = calFormat.toString(cal);
     if (!iCal.isEmpty()) {
         // This was an iCal
         return iCal;
